==> devextreme-22.1.3.tgz: package/cjs/renovation/ui/grids/data_grid_next/views/footer.js <==
/**
 * DevExtreme (cjs/renovation/ui/grids/data_grid_next/views/footer.js)
 * Version: 22.1.3
 * Build date: Mon Jun 13 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.viewFunction = exports.FooterProps = exports.FooterPlaceholder = exports.Footer = void 0;
var _inferno = require("inferno");
var _inferno2 = require("@devextreme/runtime/inferno");
var _context = require("../../../../utils/plugin/context");
var _placeholder = require("../../../../utils/plugin/placeholder");

function _extends() {
    _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var FooterPlaceholder = (0, _context.createPlaceholder)();
exports.FooterPlaceholder = FooterPlaceholder;
var viewFunction = function() {
    return (0, _inferno.createComponentVNode)(2, _placeholder.Placeholder, {
        type: FooterPlaceholder
    })
};
exports.viewFunction = viewFunction;
var FooterProps = {};
exports.FooterProps = FooterProps;
var Footer = function(_BaseInfernoComponent) {
    _inheritsLoose(Footer, _BaseInfernoComponent);

    function Footer(props) {
        var _this;
        _this = _BaseInfernoComponent.call(this, props) || this;
        _this.state = {};
        return _this
    }
    var _proto = Footer.prototype;
    _proto.render = function() {
        this.props;
        return viewFunction()
    };
    _createClass(Footer, [{
        key: "restAttributes",
        get: function() {
            var restProps = _extends({}, this.props);
            return restProps
        }
    }]);
    return Footer
}(_inferno2.BaseInfernoComponent);
exports.Footer = Footer;
Footer.defaultProps = FooterProps;

==> devextreme-22.1.4.tgz: package/cjs/renovation/ui/grids/data_grid_next/views/footer.js <==
/**
 * DevExtreme (cjs/renovation/ui/grids/data_grid_next/views/footer.js)
 * Version: 22.1.4
 * Build date: Fri Jul 22 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.viewFunction = exports.FooterProps = exports.FooterPlaceholder = exports.Footer = void 0;
var _inferno = require("inferno");
var _inferno2 = require("@devextreme/runtime/inferno");
var _context = require("../../../../utils/plugin/context");
var _placeholder = require("../../../../utils/plugin/placeholder");

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var FooterPlaceholder = (0, _context.createPlaceholder)();
exports.FooterPlaceholder = FooterPlaceholder;
var viewFunction = function() {
    return (0, _inferno.createComponentVNode)(2, _placeholder.Placeholder, {
        type: FooterPlaceholder
    })
};
exports.viewFunction = viewFunction;
var FooterProps = {};
exports.FooterProps = FooterProps;
var Footer = function(_BaseInfernoComponent) {
    _inheritsLoose(Footer, _BaseInfernoComponent);

    function Footer(props) {
        var _this;
        _this = _BaseInfernoComponent.call(this, props) || this;
        _this.state = {};
        return _this
    }
    var _proto = Footer.prototype;
    _proto.render = function() {
        this.props;
        return viewFunction()
    };
    _createClass(Footer, [{
        key: "restAttributes",
        get: function() {
            var restProps = _extends({}, this.props);
            return restProps
        }
    }]);
    return Footer
}(_inferno2.BaseInfernoComponent);
exports.Footer = Footer;
Footer.defaultProps = FooterProps;
